@@ -98,6 +98,9 @@ FAILEDOPERATION_PRIVILEGEDATAILLEGAL = 'FailedOperation.PrivilegeDataIllegal'
 # 数据库代理状态异常。
 FAILEDOPERATION_PROXYGROUPSTATUSERROR = 'FailedOperation.ProxyGroupStatusError'
 
+# 查询审计任务失败。
+FAILEDOPERATION_QUERYAUDITTASKFAILERROR = 'FailedOperation.QueryAuditTaskFailError'
+
 # 查询日志失败。
 FAILEDOPERATION_QUERYLOGERROR = 'FailedOperation.QueryLogError'
 
@@ -125,6 +128,9 @@ FAILEDOPERATION_TYPEINCONFLICT = 'FailedOperation.TypeInConflict'
 # 该IP已被占用。
 FAILEDOPERATION_VPCIPINUSEERROR = 'FailedOperation.VpcIpInUseError'
 
+# 子网中不存在该IP
+FAILEDOPERATION_VPCIPNOTINSUBNETERROR = 'FailedOperation.VpcIpNotInSubnetError'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -140,6 +146,9 @@ INTERNALERROR_AUDITDELETELOGFILEERROR = 'InternalError.AuditDeleteLogFileError'
 # 审计内部服务错误。
 INTERNALERROR_AUDITDELETEPOLICYERROR = 'InternalError.AuditDeletePolicyError'
 
+# 查询审计日志错误。
+INTERNALERROR_AUDITDESCRIBELOGERROR = 'InternalError.AuditDescribeLogError'
+
 # 审计内部服务错误。
 INTERNALERROR_AUDITERROR = 'InternalError.AuditError'
 
@@ -488,6 +497,15 @@ OPERATIONDENIED_PROXYNODECOUNTLIMITERROR = 'OperationDenied.ProxyNodeCountLimitE
 # 数据库代理升级任务中，不允许该操作。
 OPERATIONDENIED_PROXYUPGRADETASKSTATUSERROR = 'OperationDenied.ProxyUpgradeTaskStatusError'
 
+# 查询审计日志失败。
+OPERATIONDENIED_QUERYAUDITLOGSERROR = 'OperationDenied.QueryAuditLogsError'
+
+# 资源未找到。
+OPERATIONDENIED_RESOURCENOTFOUNDERROR = 'OperationDenied.ResourceNotFoundError'
+
+# 资源未找到。
+OPERATIONDENIED_RESOURCENOTFUNDERROR = 'OperationDenied.ResourceNotFundError'
+
 # 结果集超过限制，请缩小检索范围。
 OPERATIONDENIED_RESULTOVERLIMIT = 'OperationDenied.ResultOverLimit'
 
